Stan Math Library: stan/math/prim/mat/prob/wishart_log.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
wishart_log.hpp File Reference
`#include <stan/math/prim/scal/err/check_size_match.hpp>`
`#include <stan/math/prim/mat/err/check_ldlt_factor.hpp>`
`#include <stan/math/prim/mat/err/check_square.hpp>`
`#include <stan/math/prim/scal/err/check_greater.hpp>`
`#include <stan/math/prim/scal/fun/lmgamma.hpp>`
`#include <stan/math/prim/mat/fun/crossprod.hpp>`
`#include <stan/math/prim/mat/fun/columns_dot_product.hpp>`
`#include <stan/math/prim/mat/fun/trace.hpp>`
`#include <stan/math/prim/mat/fun/log_determinant_ldlt.hpp>`
`#include <stan/math/prim/mat/fun/mdivide_left_ldlt.hpp>`
`#include <stan/math/prim/mat/fun/dot_product.hpp>`
`#include <stan/math/prim/mat/fun/mdivide_left_tri_low.hpp>`
`#include <stan/math/prim/mat/fun/multiply_lower_tri_self_transpose.hpp>`
`#include <stan/math/prim/mat/meta/index_type.hpp>`
`#include <stan/math/prim/scal/fun/constants.hpp>`
`#include <stan/math/prim/scal/meta/include_summand.hpp>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<bool propto, typename T_y , typename T_dof , typename T_scale >
boost::math::tools::promote_args< T_y, T_dof, T_scale >::type | stan::math::wishart_log (const Eigen::Matrix< T_y, Eigen::Dynamic, Eigen::Dynamic > &W, const T_dof &nu, const Eigen::Matrix< T_scale, Eigen::Dynamic, Eigen::Dynamic > &S)
| The log of the Wishart density for the given W, degrees of freedom, and scale matrix. More...
template<typename T_y , typename T_dof , typename T_scale >
boost::math::tools::promote_args< T_y, T_dof, T_scale >::type | stan::math::wishart_log (const Eigen::Matrix< T_y, Eigen::Dynamic, Eigen::Dynamic > &W, const T_dof &nu, const Eigen::Matrix< T_scale, Eigen::Dynamic, Eigen::Dynamic > &S)

[ Stan Home Page ] © 2011–2016, Stan Development Team.